@@ -381,15 +381,15 @@ void VisibilityManagerPrivate::dodgeMaximized(WindowId wid)
     }
 
     auto isMaxVert = [&]() noexcept -> bool {
-        return winfo.isMaxVert()
-               || (view->screen() && view->screen()->availableSize().height() <= winfo.geometry().height()
-                   && intersects(winfo));
+        return ((winfo.isMaxVert()
+                 || (view->screen() && view->screen()->availableSize().height() <= winfo.geometry().height()))
+                && intersects(winfo));
     };
 
     auto isMaxHoriz = [&]() noexcept -> bool {
-        return winfo.isMaxHoriz()
-               || (view->screen() && view->screen()->availableSize().width() <= winfo.geometry().width()
-                   && intersects(winfo));
+        return ((winfo.isMaxHoriz()
+                 || (view->screen() && view->screen()->availableSize().width() <= winfo.geometry().width()))
+                && intersects(winfo));
     };
 
     //!dont send false raiseDock signal when containing mouse
@@ -475,7 +475,7 @@ inline void VisibilityManagerPrivate::restoreConfig()
         return;
 
     auto config = view->containment()->config();
-    timerShow.setInterval(config.readEntry("timerShow", 200));
+    timerShow.setInterval(config.readEntry("timerShow", 0));
     timerHide.setInterval(config.readEntry("timerHide", 700));
     emit q->timerShowChanged();
     emit q->timerHideChanged();
